#!/usr/bin/python
# -*- coding: utf8 -*-
import pydumpfs
pydumpfs.main()
